KokoroConfig class

Core Kokoro configuration

Constructors

KokoroConfig({required String modelPath, required String voicesPath, bool isInt8 = false, TokenizerConfig? tokenizerConfig})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isInt8 bool
Whether the model is an int8 quantized model
final
modelPath String
Path to the model file
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenizerConfig TokenizerConfig?
Tokenizer configuration
final
voicesPath String
Path to the voices file
final

Methods

copyWith({String? modelPath, String? voicesPath, bool? isInt8, TokenizerConfig? tokenizerConfig}) KokoroConfig
Create a copy of this config with updated values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() → void
Validates the configuration

Operators

operator ==(Object other) bool
The equality operator.
inherited