TtsResult class

Represents the result of a text-to-speech operation

Constructors

TtsResult({required List<num> audio, required int sampleRate, required double duration, required String phonemes})
Creates a TTS result
const

Properties

audio List<num>
The generated audio samples
final
duration double
Duration of the audio in seconds
final
hashCode int
The hash code for this object.
no setterinherited
phonemes String
The phonemes that were used to generate the audio
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
The sample rate of the audio
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInt16PCM() Int16List
Convert to Int16 audio for playback compatibility
toPcm() Float64List
Convert the audio samples to a PCM audio buffer
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited