AudioUtils class
Audio processing utilities for Kokoro TTS
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
concatenateAudio(
List< List< audioBuffers) → List<num> >num> - Concatenates multiple audio buffers
-
rms(
List< num> audio, {required int frameLength, required int hopLength}) → Float32List - Calculate RMS (Root Mean Square) of audio frames
-
trimSilence(
List< num> audio, {double topDb = 60.0, int frameLength = 2048, int hopLength = 512}) → (List<num> , List<int> ) - Trims silence from the beginning and end of an audio buffer